@@ -1,7 +1,7 @@
 from python_utils import __about__
 
 
-def test_definitions():
+def test_definitions() -> None:
     # The setup.py requires this so we better make sure they exist :)
     assert __about__.__version__
     assert __about__.__author__
